Package 'anivis'

Title: An R package for visualizing movement data and diagnostics
Description: An R package for visualizing movement data and diagnostics.
Authors: Mikkel Roald-Arbøl [aut, cre] (ORCID: <https://orcid.org/0000-0002-9998-0058>)
Maintainer: Mikkel Roald-Arbøl <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-27 07:51:39 UTC
Source: https://github.com/animovement/anivis

Help Index


Visualize the distribution of confidence values for each keypoint

Description

This function generates histograms showing the distribution of confidence values for each keypoint in the dataset.

Usage

## S3 method for class 'plot_check_confidence'
plot(x, ...)

Arguments

x

A data frame containing at least the columns keypoint and confidence.

...

Additional arguments for ggplot2

Value

A ggplot boxplot of the confidence per keypoint.


Animovement ggplot2 theme

Description

A custom ggplot2 theme for animovement plots.

Usage

theme_animovement()

Value

A ggplot2 theme object.